@@ -9,9 +9,8 @@
 //! **Rust 1.51** at a minimum.
 //!
 //! # Goals
-//! - No heap allocations (`no_std`-friendly)
-//! - Constant-time by default: if we add variable-time operations in the future
-//!   they will be secondary and explicitly labeled.
+//! - No heap allocations i.e. `no_std`-friendly.
+//! - Constant-time by default using traits from the [`subtle`] crate.
 //! - Leverage what is possible today with const generics on `stable` rust.
 //! - Support `const fn` as much as possible, including decoding big integers from
 //!   bytes/hex and performing arithmetic operations on them, with the goal of
@@ -36,11 +35,14 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/crypto-bigint/0.1.0"
+    html_root_url = "https://docs.rs/crypto-bigint/0.2.0"
 )]
 #![forbid(unsafe_code, clippy::unwrap_used)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
 
+#[cfg(all(feature = "alloc", test))]
+extern crate alloc;
+
 #[macro_use]
 mod macros;
 
@@ -53,13 +55,7 @@ mod array;
 mod checked;
 mod wrapping;
 
-pub use crate::{
-    checked::Checked,
-    limb::Limb,
-    traits::{Concat, NumBits, NumBytes, Split},
-    uint::*,
-    wrapping::Wrapping,
-};
+pub use crate::{checked::Checked, limb::Limb, traits::*, uint::*, wrapping::Wrapping};
 pub use subtle;
 
 #[cfg(feature = "generic-array")]
